@@ -7,7 +7,6 @@
 extern void levenshtein(void *, void *, void *, void *, void *);
 extern void makeBlockingPairs(void *, void *, void *, void *);
 extern void mygllm(void *, void *, void *, void *, void *, void *, void *, void *, void *);
-extern void pho_h(void *, void *, void *);
 extern void soundex(void *, void *, void *);
 
 /* .Call calls */
@@ -17,7 +16,6 @@ static const R_CMethodDef CEntries[] = {
     {".levenshtein_sym",       (DL_FUNC) &levenshtein,       5},
     {".makeBlockingPairs_sym", (DL_FUNC) &makeBlockingPairs, 4},
     {".mygllm_sym",            (DL_FUNC) &mygllm,            9},
-    {".pho_h_sym",             (DL_FUNC) &pho_h,             3},
     {".soundex_sym",           (DL_FUNC) &soundex,           3},
     {NULL, NULL, 0}
 };
